@@ -1,8 +1,22 @@
 use clashctl_core::model::ConnectionWithSpeed;
+use serde::{Deserialize, Serialize};
+use smart_default::SmartDefault;
 
 use crate::{EndlessSelf, OrderBy, SortMethod, SortOrder};
 
-#[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, strum::EnumIter)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    PartialOrd,
+    Ord,
+    Serialize,
+    Deserialize,
+    SmartDefault,
+    strum::EnumIter,
+)]
+#[serde(rename_all = "lowercase")]
 enum ConSortBy {
     Host,
     Down,
@@ -11,6 +25,7 @@ enum ConSortBy {
     UpSpeed,
     Chains,
     Rule,
+    #[default]
     Time,
     Src,
     Dest,
@@ -33,6 +48,8 @@ impl EndlessSelf for ConSortBy {
     }
 }
 
+#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Serialize, Deserialize, Default)]
+#[serde(rename_all = "lowercase")]
 pub struct ConSort {
     by: ConSortBy,
     order: SortOrder,
